---
icon: material/help-circle
---

# Help

## First steps

!!! tip
    "Search bar" Use the search bar from this documentation page to find
    what you are looking for.

!!! tip
    "Look at the examples" The examples tab has might give you some insides
    into how to use the tool.

## Further help

!!! question "Open an Issue"
    Open an [issue][new_issue] describing your problem.

!!! warning
    To avoid duplicating issues, please search our [issue tracker][issues] before filing a new issue.

## General ASP support

- Take a look at the [support page][support_page] of Potassco.

[support_page]: https://potassco.org/support/
[new_issue]: https://github.com/potassco/benchmark-tool/issues/new
[issues]: https://github.com/potassco/benchmark-tool/issues
